#!/bin/bash

# 定义变量
FRPC_VERSION="0.61.1"
INSTALL_DIR="/usr/local/bin"
SERVICE_NAME="frpc"
CONFIG_DIR="/etc/frp"
CONFIG_FILE="$CONFIG_DIR/frpc.toml"
FRPC_BIN="$INSTALL_DIR/frpc"

# 检测系统架构
ARCH=$(uname -m)
case $ARCH in
    x86_64)
        ARCH="amd64"
        ;;
    aarch64)
        ARCH="arm64"
        ;;
    armv7l)
        ARCH="arm"
        ;;
    *)
        echo "不支持的架构: $ARCH"
        exit 1
        ;;
esac

# 检查 frpc 是否已安装
if [ -f "$FRPC_BIN" ]; then
    echo "frpc 已安装，跳过下载步骤。"
else
    # 下载 frpc
    echo "正在下载 frpc v$FRPC_VERSION ..."
    DOWNLOAD_URL="https://ghub.z1.mk/https://github.com/fatedier/frp/releases/download/v${FRPC_VERSION}/frp_${FRPC_VERSION}_linux_${ARCH}.tar.gz"
    wget -q --show-progress -O /tmp/frp.tar.gz $DOWNLOAD_URL
fi
# 解压并安装
echo "正在安装 frpc ..."
tar -xzf /tmp/frp.tar.gz -C /tmp
sudo mv /tmp/frp_${FRPC_VERSION}_linux_${ARCH}/frpc $INSTALL_DIR/
sudo chmod +x $INSTALL_DIR/frpc

# 清理临时文件
rm -rf /tmp/frp_${FRPC_VERSION}_linux_${ARCH} /tmp/frp.tar.gz

# 创建配置文件目录
echo "正在创建配置文件目录 ..."
sudo mkdir -p $CONFIG_DIR

# 检查配置文件是否存在
if [ -f "$CONFIG_FILE" ]; then
    echo "配置文件已存在，跳过生成步骤。"
else
    # 用户输入 frps 服务器地址和端口号
    read -p "请输入 frps 服务器地址: " FRPS_SERVER
    read -p "请输入 frps 服务器端口号: " FRPS_PORT

    # 写入 TOML 配置文件
    echo "正在写入 TOML 配置文件 ..."
    sudo bash -c "cat > $CONFIG_FILE" <<EOF
[common]
server_addr = $FRPS_SERVER
server_port = $FRPS_PORT

auth.method = "token"
auth.token = "swz"

webServer.addr = "0.0.0.0"
webServer.port = 7878
webServer.user = "admin"
webServer.password = "bjyc3219727"
webServer.pprofEnable = false

[[proxies]]
name = "ssh_random"
type = "tcp"
localIP = "10.105.56.8"
localPort = 1030
remotePort = 1030
EOF
fi

# 检查 Systemd 服务是否已存在
SERVICE_FILE="/etc/systemd/system/$SERVICE_NAME.service"
if [ -f "$SERVICE_FILE" ]; then
    echo "Systemd 服务已存在，跳过生成步骤。"
else
    # 创建 Systemd 服务
    echo "正在创建 Systemd 服务 ..."
    sudo bash -c "cat > $SERVICE_FILE" <<EOF
[Unit]
Description=Frp Client Service
After=network.target

[Service]
Type=simple
ExecStart=$INSTALL_DIR/frpc -c $CONFIG_FILE
Restart=on-failure
User=nobody
RestartSec=5s

[Install]
WantedBy=multi-user.target
EOF

    # 重载 Systemd 并启动服务
    sudo systemctl daemon-reload
    sudo systemctl enable $SERVICE_NAME
    sudo systemctl start $SERVICE_NAME
fi

# 检查服务状态
echo "frpc 安装完成！"
echo "服务状态："
sudo systemctl status $SERVICE_NAME
